@@ -1,6 +1,5 @@
 # fmt: off
 import sys
-from typing import TypeVar, Union
 
 from loguru import logger
 
@@ -8,10 +7,6 @@ logger.remove()
 logger.add(sys.stderr, format="", colorize=True, backtrace=False, diagnose=True)
 
 
-T = TypeVar("T")
-Name = str
-
-
 def foo(a, /, b, *, c, **d): 1 / 0
 
 
