@@ -6,7 +6,7 @@ from loguru import logger
 def test_diagnose(writer):
     logger.add(writer, format="{message}", diagnose=True)
     try:
-        1 / 0
+        1 / 0  # noqa: B018
     except Exception:
         logger.exception("")
     result_with = writer.read().strip()
@@ -16,7 +16,7 @@ def test_diagnose(writer):
 
     logger.add(writer, format="{message}", diagnose=False)
     try:
-        1 / 0
+        1 / 0  # noqa: B018
     except Exception:
         logger.exception("")
     result_without = writer.read().strip()
