@@ -3,12 +3,16 @@ import platform
 import re
 import subprocess
 import sys
+import traceback
+from unittest.mock import MagicMock
 
 import pytest
 
+from loguru import logger
+
 
 def normalize(exception):
-    """Normalize exception output for reproducible test cases"""
+    """Normalize exception output for reproducible test cases."""
     if os.name == "nt":
         exception = re.sub(
             r'File[^"]+"[^"]+\.py[^"]*"', lambda m: m.group().replace("\\", "/"), exception
@@ -78,7 +82,7 @@ def normalize(exception):
 
 
 def generate(output, outpath):
-    """Generate new output file if exception formatting is updated"""
+    """Generate new output file if exception formatting is updated."""
     os.makedirs(os.path.dirname(outpath), exist_ok=True)
     with open(outpath, "w") as file:
         file.write(output)
@@ -198,6 +202,7 @@ def test_exception_ownership(filename):
     "filename",
     [
         "assertionerror_without_traceback",
+        "broken_but_decorated_repr",
         "catch_as_context_manager",
         "catch_as_decorator_with_parentheses",
         "catch_as_decorator_without_parentheses",
@@ -214,6 +219,9 @@ def test_exception_ownership(filename):
         "message_formatting_with_context_manager",
         "message_formatting_with_decorator",
         "nested_with_reraise",
+        "one_liner_recursion",
+        "recursion_error",
+        "repeated_lines",
         "syntaxerror_without_traceback",
         "sys_tracebacklimit",
         "sys_tracebacklimit_negative",
@@ -223,11 +231,14 @@ def test_exception_ownership(filename):
     ],
 )
 def test_exception_others(filename):
+    if filename == "recursion_error" and platform.python_implementation() == "PyPy":
+        pytest.skip("RecursionError is not reliable on PyPy")
+
     compare_exception("others", filename)
 
 
 @pytest.mark.parametrize(
-    "filename, minimum_python_version",
+    ("filename", "minimum_python_version"),
     [
         ("type_hints", (3, 6)),
         ("positional_only_argument", (3, 8)),
@@ -257,8 +268,6 @@ def test_exception_modern(filename, minimum_python_version):
 def test_group_exception_using_backport(writer):
     from exceptiongroup import ExceptionGroup
 
-    from loguru import logger
-
     logger.add(writer, backtrace=True, diagnose=True, colorize=False, format="")
 
     try:
@@ -267,3 +276,38 @@ def test_group_exception_using_backport(writer):
         logger.exception("")
 
     assert writer.read().strip().startswith("+ Exception Group Traceback (most recent call last):")
+
+
+def test_invalid_format_exception_only_no_output(writer, monkeypatch):
+    logger.add(writer, backtrace=True, diagnose=True, colorize=False, format="")
+
+    with monkeypatch.context() as context:
+        context.setattr(traceback, "format_exception_only", lambda _e, _v: [])
+        error = ValueError(0)
+        logger.opt(exception=error).error("Error")
+
+        assert writer.read() == "\n"
+
+
+def test_invalid_format_exception_only_indented_error_message(writer, monkeypatch):
+    logger.add(writer, backtrace=True, diagnose=True, colorize=False, format="")
+
+    with monkeypatch.context() as context:
+        context.setattr(traceback, "format_exception_only", lambda _e, _v: ["    ValueError: 0\n"])
+        error = ValueError(0)
+        logger.opt(exception=error).error("Error")
+
+        assert writer.read() == "\n    ValueError: 0\n"
+
+
+@pytest.mark.skipif(sys.version_info < (3, 11), reason="No builtin GroupedException")
+def test_invalid_grouped_exception_no_exceptions(writer):
+    error = MagicMock(spec=ExceptionGroup)  # noqa: F821
+    error.__cause__ = None
+    error.__context__ = None
+    error.__traceback__ = None
+
+    logger.add(writer, backtrace=True, diagnose=True, colorize=False, format="")
+    logger.opt(exception=error).error("Error")
+
+    assert writer.read().strip().startswith("| unittest.mock.MagicMock:")
