@@ -303,7 +303,7 @@ def test_exception_during_retention_at_rotation_not_caught(freeze_time, tmp_path
             catch=False,
             delay=delay,
         )
-        with pytest.raises(OSError, match=r"Retention error"):
+        with pytest.raises(OSError, match="^Retention error$"):
             logger.debug("AAA")
         frozen.tick()
         logger.debug("BBB")
@@ -332,7 +332,7 @@ def test_exception_during_retention_at_remove(tmp_path, capsys, delay):
     )
     logger.debug("AAA")
 
-    with pytest.raises(OSError, match=r"Retention error"):
+    with pytest.raises(OSError, match="^Retention error$"):
         logger.remove(i)
 
     logger.debug("Nope")
@@ -344,15 +344,20 @@ def test_exception_during_retention_at_remove(tmp_path, capsys, delay):
 
 
 @pytest.mark.parametrize("retention", [datetime.time(12, 12, 12), os, object()])
-def test_invalid_retention(retention):
+def test_invalid_retention_type(retention):
     with pytest.raises(TypeError):
         logger.add("test.log", retention=retention)
 
 
 @pytest.mark.parametrize(
-    "retention",
-    ["W5", "monday at 14:00", "sunday", "nope", "5 MB", "3 hours 2 dayz", "d", "H", "__dict__"],
+    "retention", ["W5", "monday at 14:00", "sunday", "nope", "d", "H", "__dict__"]
 )
-def test_unkown_retention(retention):
-    with pytest.raises(ValueError):
+def test_unparsable_retention(retention):
+    with pytest.raises(ValueError, match="^Cannot parse retention from: '[^']+'$"):
+        logger.add("test.log", retention=retention)
+
+
+@pytest.mark.parametrize("retention", ["5 MB", "3 hours 2 dayz"])
+def test_invalid_value_retention_duration(retention):
+    with pytest.raises(ValueError, match="^Invalid unit value while parsing duration: '[^']+'$"):
         logger.add("test.log", retention=retention)
