@@ -105,7 +105,7 @@ def test_size_rotation(freeze_time, tmp_path, size):
 
 
 @pytest.mark.parametrize(
-    "when, hours",
+    ("when", "hours"),
     [
         # hours = [
         #   Should not trigger, should trigger, should not trigger, should trigger, should trigger
@@ -122,7 +122,7 @@ def test_size_rotation(freeze_time, tmp_path, size):
         ("w6 at 00", [8, 24 * 7, 24 * 6, 24, 24 * 8]),
         (" W6 at 13 ", [0.5, 1, 24 * 6, 24 * 6, 365 * 24]),
         ("w2  at  11:00:00 AM", [48 + 22, 3, 24 * 6, 24, 366 * 24]),
-        ("MoNdAy at 11:00:30.123", [22, 24, 24, 24 * 7, 24 * 7]),
+        ("MonDaY at 11:00:30.123", [22, 24, 24, 24 * 7, 24 * 7]),
         ("sunday", [0.1, 24 * 7 - 10, 24, 24 * 6, 24 * 7]),
         ("SUNDAY at 11:00", [1, 24 * 7, 2, 24 * 7, 30 * 12]),
         ("sunDAY at 1:0:0.0 pm", [0.9, 0.2, 24 * 7 - 2, 3, 24 * 8]),
@@ -755,30 +755,31 @@ def test_time_rotation_reopening_native(tmp_path_local, delay):
     reason="Testing implementation specific to Linux",
 )
 def test_time_rotation_reopening_xattr_attributeerror(tmp_path_local, monkeypatch, delay):
-    monkeypatch.delattr(os, "setxattr")
-    monkeypatch.delattr(os, "getxattr")
-    get_ctime, set_ctime = load_ctime_functions()
+    with monkeypatch.context() as context:
+        context.delattr(os, "setxattr")
+        context.delattr(os, "getxattr")
+        get_ctime, set_ctime = load_ctime_functions()
 
-    monkeypatch.setattr(loguru._file_sink, "get_ctime", get_ctime)
-    monkeypatch.setattr(loguru._file_sink, "set_ctime", set_ctime)
+        context.setattr(loguru._file_sink, "get_ctime", get_ctime)
+        context.setattr(loguru._file_sink, "set_ctime", set_ctime)
 
-    filepath = tmp_path_local / "test.log"
-    i = logger.add(filepath, format="{message}", delay=delay, rotation="2 s")
-    time.sleep(1)
-    logger.info("1")
-    logger.remove(i)
-    time.sleep(1.5)
-    i = logger.add(filepath, format="{message}", delay=delay, rotation="2 s")
-    logger.info("2")
-    logger.remove(i)
-    check_dir(tmp_path_local, size=1)
-    assert filepath.read_text() == "1\n2\n"
-    time.sleep(2.5)
-    i = logger.add(filepath, format="{message}", delay=delay, rotation="2 s")
-    logger.info("3")
-    logger.remove(i)
-    check_dir(tmp_path_local, size=2)
-    assert filepath.read_text() == "3\n"
+        filepath = tmp_path_local / "test.log"
+        i = logger.add(filepath, format="{message}", delay=delay, rotation="2 s")
+        time.sleep(1)
+        logger.info("1")
+        logger.remove(i)
+        time.sleep(1.5)
+        i = logger.add(filepath, format="{message}", delay=delay, rotation="2 s")
+        logger.info("2")
+        logger.remove(i)
+        check_dir(tmp_path_local, size=1)
+        assert filepath.read_text() == "1\n2\n"
+        time.sleep(2.5)
+        i = logger.add(filepath, format="{message}", delay=delay, rotation="2 s")
+        logger.info("3")
+        logger.remove(i)
+        check_dir(tmp_path_local, size=2)
+        assert filepath.read_text() == "3\n"
 
 
 @pytest.mark.parametrize("delay", [False, True])
@@ -790,52 +791,54 @@ def test_time_rotation_reopening_xattr_attributeerror(tmp_path_local, monkeypatc
     reason="Testing implementation specific to Linux",
 )
 def test_time_rotation_reopening_xattr_oserror(tmp_path_local, monkeypatch, delay):
-    monkeypatch.setattr(os, "setxattr", Mock(side_effect=OSError))
-    monkeypatch.setattr(os, "getxattr", Mock(side_effect=OSError))
-    get_ctime, set_ctime = load_ctime_functions()
+    with monkeypatch.context() as context:
+        context.setattr(os, "setxattr", Mock(side_effect=OSError))
+        context.setattr(os, "getxattr", Mock(side_effect=OSError))
+        get_ctime, set_ctime = load_ctime_functions()
 
-    monkeypatch.setattr(loguru._file_sink, "get_ctime", get_ctime)
-    monkeypatch.setattr(loguru._file_sink, "set_ctime", set_ctime)
+        context.setattr(loguru._file_sink, "get_ctime", get_ctime)
+        context.setattr(loguru._file_sink, "set_ctime", set_ctime)
 
-    filepath = tmp_path_local / "test.log"
-    i = logger.add(filepath, format="{message}", delay=delay, rotation="2 s")
-    time.sleep(1)
-    logger.info("1")
-    logger.remove(i)
-    time.sleep(1.5)
-    i = logger.add(filepath, format="{message}", delay=delay, rotation="2 s")
-    logger.info("2")
-    logger.remove(i)
-    check_dir(tmp_path_local, size=1)
-    assert filepath.read_text() == "1\n2\n"
-    time.sleep(2.5)
-    i = logger.add(filepath, format="{message}", delay=delay, rotation="2 s")
-    logger.info("3")
-    logger.remove(i)
-    check_dir(tmp_path_local, size=2)
-    assert filepath.read_text() == "3\n"
+        filepath = tmp_path_local / "test.log"
+        i = logger.add(filepath, format="{message}", delay=delay, rotation="2 s")
+        time.sleep(1)
+        logger.info("1")
+        logger.remove(i)
+        time.sleep(1.5)
+        i = logger.add(filepath, format="{message}", delay=delay, rotation="2 s")
+        logger.info("2")
+        logger.remove(i)
+        check_dir(tmp_path_local, size=1)
+        assert filepath.read_text() == "1\n2\n"
+        time.sleep(2.5)
+        i = logger.add(filepath, format="{message}", delay=delay, rotation="2 s")
+        logger.info("3")
+        logger.remove(i)
+        check_dir(tmp_path_local, size=2)
+        assert filepath.read_text() == "3\n"
 
 
 @pytest.mark.skipif(os.name != "nt", reason="Testing implementation specific to Windows")
 def test_time_rotation_windows_no_setctime(tmp_path, monkeypatch):
     import win32_setctime
 
-    monkeypatch.setattr(win32_setctime, "SUPPORTED", False)
-    monkeypatch.setattr(win32_setctime, "setctime", Mock())
+    with monkeypatch.context() as context:
+        context.setattr(win32_setctime, "SUPPORTED", False)
+        context.setattr(win32_setctime, "setctime", Mock())
 
-    filepath = tmp_path / "test.log"
-    logger.add(filepath, format="{message}", rotation="2 s")
-    logger.info("1")
-    time.sleep(1.5)
-    logger.info("2")
-    check_dir(tmp_path, size=1)
-    assert filepath.read_text() == "1\n2\n"
-    time.sleep(1)
-    logger.info("3")
-    check_dir(tmp_path, size=2)
-    assert filepath.read_text() == "3\n"
+        filepath = tmp_path / "test.log"
+        logger.add(filepath, format="{message}", rotation="2 s")
+        logger.info("1")
+        time.sleep(1.5)
+        logger.info("2")
+        check_dir(tmp_path, size=1)
+        assert filepath.read_text() == "1\n2\n"
+        time.sleep(1)
+        logger.info("3")
+        check_dir(tmp_path, size=2)
+        assert filepath.read_text() == "3\n"
 
-    assert not win32_setctime.setctime.called
+        assert not win32_setctime.setctime.called
 
 
 @pytest.mark.parametrize("exception", [ValueError, OSError])
@@ -843,21 +846,22 @@ def test_time_rotation_windows_no_setctime(tmp_path, monkeypatch):
 def test_time_rotation_windows_setctime_exception(tmp_path, monkeypatch, exception):
     import win32_setctime
 
-    monkeypatch.setattr(win32_setctime, "setctime", Mock(side_effect=exception))
+    with monkeypatch.context() as context:
+        context.setattr(win32_setctime, "setctime", Mock(side_effect=exception))
 
-    filepath = tmp_path / "test.log"
-    logger.add(filepath, format="{message}", rotation="2 s")
-    logger.info("1")
-    time.sleep(1.5)
-    logger.info("2")
-    check_dir(tmp_path, size=1)
-    assert filepath.read_text() == "1\n2\n"
-    time.sleep(1)
-    logger.info("3")
-    check_dir(tmp_path, size=2)
-    assert filepath.read_text() == "3\n"
+        filepath = tmp_path / "test.log"
+        logger.add(filepath, format="{message}", rotation="2 s")
+        logger.info("1")
+        time.sleep(1.5)
+        logger.info("2")
+        check_dir(tmp_path, size=1)
+        assert filepath.read_text() == "1\n2\n"
+        time.sleep(1)
+        logger.info("3")
+        check_dir(tmp_path, size=2)
+        assert filepath.read_text() == "3\n"
 
-    assert win32_setctime.setctime.called
+        assert win32_setctime.setctime.called
 
 
 def test_function_rotation(freeze_time, tmp_path):
@@ -996,7 +1000,7 @@ def test_exception_during_rotation_not_caught(tmp_path, capsys):
         catch=False,
     )
 
-    with pytest.raises(OSError, match=r"Rotation error"):
+    with pytest.raises(OSError, match="^Rotation error$"):
         logger.info("A")
 
     logger.info("B")
@@ -1057,7 +1061,7 @@ def test_recipe_rotation_both_size_and_time(freeze_time, tmp_path):
 @pytest.mark.parametrize(
     "rotation", [object(), os, datetime.date(2017, 11, 11), datetime.datetime.now(), 1j]
 )
-def test_invalid_rotation(rotation):
+def test_invalid_rotation_type(rotation):
     with pytest.raises(TypeError):
         logger.add("test.log", rotation=rotation)
 
@@ -1065,31 +1069,51 @@ def test_invalid_rotation(rotation):
 @pytest.mark.parametrize(
     "rotation",
     [
-        "w7",
-        "w10",
         "w-1",
         "h",
         "M",
         "w1at13",
         "www",
-        "13 at w2",
         "w",
         "K",
-        "tufy MB",
-        "111.111.111 kb",
-        "3 Ki",
-        "2017.11.12",
-        "11:99",
+        "foobar MB",
         "01:00:00!UTC",
-        "monday at 2017",
-        "e days",
-        "2 days 8 pouooi",
         "foobar",
-        "w5 at [not|a|time]",
-        "[not|a|day] at 12:00",
         "__dict__",
     ],
 )
-def test_unknown_rotation(rotation):
-    with pytest.raises(ValueError):
+def test_unparsable_rotation(rotation):
+    with pytest.raises(ValueError, match="^Cannot parse rotation from: '[^']+'$"):
+        logger.add("test.log", rotation=rotation)
+
+
+@pytest.mark.parametrize("rotation", ["w7", "w10", "13 at w2", "[not|a|day] at 12:00"])
+def test_invalid_day_rotation(rotation):
+    with pytest.raises(ValueError, match="^Invalid day while parsing daytime: '[^']+'$"):
+        logger.add("test.log", rotation=rotation)
+
+
+@pytest.mark.parametrize(
+    "rotation", ["2017.11.12", "11:99", "monday at 2017", "w5 at [not|a|time]"]
+)
+def test_invalid_time_rotation(rotation):
+    with pytest.raises(ValueError, match="^Invalid time while parsing daytime: '[^']+'$"):
+        logger.add("test.log", rotation=rotation)
+
+
+@pytest.mark.parametrize("rotation", ["111.111.111 kb", "e KB"])
+def test_invalid_value_size_rotation(rotation):
+    with pytest.raises(ValueError, match="^Invalid float value while parsing size: '[^']+'$"):
+        logger.add("test.log", rotation=rotation)
+
+
+@pytest.mark.parametrize("rotation", ["2 days 8 foobar", "1 foobar 3 days", "3 Ki"])
+def test_invalid_unit_rotation_duration(rotation):
+    with pytest.raises(ValueError, match="^Invalid unit value while parsing duration: '[^']+'$"):
+        logger.add("test.log", rotation=rotation)
+
+
+@pytest.mark.parametrize("rotation", ["e days", "1.2.3 days"])
+def test_invalid_value_rotation_duration(rotation):
+    with pytest.raises(ValueError, match="^Invalid float value while parsing duration: '[^']+'$"):
         logger.add("test.log", rotation=rotation)
