@@ -11,15 +11,15 @@ class StopSinkError:
         print(message, end="")
 
     def stop(self):
-        raise Exception("Stop error")
+        raise OSError("Stop error")
 
 
-def test_remove_all(tmpdir, writer, capsys):
-    file = tmpdir.join("test.log")
+def test_remove_all(tmp_path, writer, capsys):
+    file = tmp_path / "test.log"
 
     logger.debug("This shouldn't be printed.")
 
-    logger.add(str(file), format="{message}")
+    logger.add(file, format="{message}")
     logger.add(sys.stdout, format="{message}")
     logger.add(sys.stderr, format="{message}")
     logger.add(writer, format="{message}")
@@ -35,7 +35,7 @@ def test_remove_all(tmpdir, writer, capsys):
 
     out, err = capsys.readouterr()
 
-    assert file.read() == expected
+    assert file.read_text() == expected
     assert out == expected
     assert err == expected
     assert writer.read() == expected
@@ -58,18 +58,18 @@ def test_remove_enqueue(writer):
     assert writer.read() == "1\n"
 
 
-def test_remove_enqueue_filesink(tmpdir):
-    file = tmpdir.join("test.log")
-    i = logger.add(str(file), format="{message}", enqueue=True)
+def test_remove_enqueue_filesink(tmp_path):
+    file = tmp_path / "test.log"
+    i = logger.add(file, format="{message}", enqueue=True)
     logger.debug("1")
     logger.remove(i)
-    assert file.read() == "1\n"
+    assert file.read_text() == "1\n"
 
 
 def test_exception_in_stop_during_remove_one(capsys):
     i = logger.add(StopSinkError(), catch=False, format="{message}")
     logger.info("A")
-    with pytest.raises(Exception, match=r"Stop error"):
+    with pytest.raises(OSError, match=r"Stop error"):
         logger.remove(i)
     logger.info("Nope")
 
@@ -83,12 +83,12 @@ def test_exception_in_stop_not_caught_during_remove_all(capsys):
     logger.add(StopSinkError(), catch=False, format="{message}")
     logger.add(StopSinkError(), catch=False, format="{message}")
 
-    with pytest.raises(Exception, match=r"Stop error"):
+    with pytest.raises(OSError, match=r"Stop error"):
         logger.remove()
 
     logger.info("A")
 
-    with pytest.raises(Exception, match=r"Stop error"):
+    with pytest.raises(OSError, match=r"Stop error"):
         logger.remove()
 
     logger.info("Nope")
